@@ -335,11 +335,28 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
   desktop_plugin->time_to_update = earliest_update_end_time;
 }
 
+static string
+cal_put_age_on_summary(const time_t& born,
+		       const time_t& birthday,
+		       const string& summary)
+{
+  struct tm* birthday_time = localtime(&birthday);
+  int age = birthday_time->tm_year;
+  birthday_time = localtime(&born); 
+  age -= birthday_time->tm_year;
+  gchar* new_summary_c = g_strdup_printf("%s (%d)", summary.c_str(), age);
+  string new_summary(new_summary_c);
+  g_free(new_summary_c);
+  return new_summary;
+}
+
 static void
 cal_read_ccompnents_for_calendar(CCalendar* calendar,
 				 time_t start_time,
 				 time_t end_time,
-				 SortedCComponentSet& all_components)
+				 SortedCComponentSet& all_components,
+				 gboolean birthday_only,
+				 CalHomePlugin* desktop_plugin)
 {
   int error = 0;
   int offset = 0;
@@ -352,27 +369,30 @@ cal_read_ccompnents_for_calendar(CCalendar* calendar,
 									   limit,
 									   offset,
 									   error);
-  
     size = calendars_components.size();
     offset+=limit;
     time_t last_start_date = start_time;
     for(int k = 0;k<calendars_components.size();++k)
     {
-      time_t x = calendars_components[k]->getDateStart();
       CComponent* component = calendars_components[k];
       vector<time_t> instance_times =
 	component->getInstanceTimes(last_start_date, 
 				    end_time);
-    
       // Remove Task Components now
       // others are cleaned up later
-      if(calendars_components[k]->getType()==2)
+      if(calendars_components[k]->getType()==2 ||
+	 (!birthday_only && calendars_components[k]->getType()==4) ||
+	 (birthday_only && calendars_components[k]->getType()!=4)
+	 )
       {
 	delete calendars_components[k];
       }
       else
+      {
 	if(instance_times.empty())
+	{
 	  all_components.insert(component);
+	}
 	else
 	{
 	  for(vector<time_t>::const_iterator iter = instance_times.begin();
@@ -382,9 +402,19 @@ cal_read_ccompnents_for_calendar(CCalendar* calendar,
 	    // clone entry with instance time as start time
 	    CComponent* c = new CComponent(*component);
 	    c->setDateStart(*iter);
+	    if(c->getType() == 4 &&
+	       desktop_plugin->show_age)
+	    {
+	      string new_summary = cal_put_age_on_summary(component->getDateStart(), 
+							  c->getDateStart(),
+							  c->getSummary());
+	      c->setSummary(new_summary);
+	    }
 	    all_components.insert(c);
 	  }
+	  delete component;
 	}
+      }
     }
   }while(size !=0 );
 }
@@ -398,6 +428,10 @@ cal_read_ccomponents_all_visible(SortedCComponentSet& all_components,
   time_t end_time = cal_home_advance_date_by_time_period(&end_date,
 							 desktop_plugin->cal_time_period);
 
+  struct tm today_midnight; 
+  cal_home_time_today_midnight(&today_midnight);
+  time_t today_midnight_time = mktime(&today_midnight);
+
   for(int i=0;i<desktop_plugin->number_visible_cals;++i)
   {
     int error = 0;
@@ -405,9 +439,17 @@ cal_read_ccomponents_all_visible(SortedCComponentSet& all_components,
     if(error == 500)
     {
       cal_read_ccompnents_for_calendar(cal,
-				       start_time,
+				       start_time+1,
 				       end_time,
-				       all_components);
+				       all_components, FALSE,
+				       desktop_plugin);
+      // gnark, birthday events start and end
+      // at 00:00:00
+      cal_read_ccompnents_for_calendar(cal,
+				       today_midnight_time,
+				       end_time,
+				       all_components, TRUE,
+				       desktop_plugin);
     }
     delete cal;
   }
