@@ -24,6 +24,7 @@
 #define CAL_HP_KEY_LAUNCH_VIEW "launch_view"
 #define CAL_HP_KEY_CAL_ROW_COUNT "cal_row_count"
 #define CAL_HP_KEY_CAL_TIME_PERIOD "cal_time_period"
+#define CAL_HP_KEY_CAL_SHOW_AGE "cal_show_age"
 #define CAL_HOME_PLUGIN_SETTINGS_FILE "/.cal_home_widget"
 
 void 
@@ -67,6 +68,13 @@ cal_home_read_settings(CalHomePlugin *desktop_plugin)
 									     NULL));
       
     }
+    if(g_key_file_has_key(keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_SHOW_AGE, NULL))
+    {
+      desktop_plugin->show_age = g_key_file_get_boolean(keyFile, 
+							desktop_plugin->iD, 
+							CAL_HP_KEY_CAL_SHOW_AGE,
+							NULL);
+    }
   }
   g_key_file_free(keyFile);
   g_free(fileName);
@@ -91,7 +99,7 @@ cal_home_save_settings(CalHomePlugin* desktop_plugin)
   g_key_file_set_integer (keyFile, desktop_plugin->iD, CAL_HP_KEY_LAUNCH_VIEW, desktop_plugin->launch_view);
   g_key_file_set_integer (keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_ROW_COUNT, desktop_plugin->cal_row_count);
   g_key_file_set_integer (keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_TIME_PERIOD, desktop_plugin->cal_time_period);
-
+  g_key_file_set_boolean (keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_SHOW_AGE, desktop_plugin->show_age);
   fileData = g_key_file_to_data (keyFile, &size, NULL);
   g_file_set_contents(filename, fileData, size, NULL);
 
